@@ -170,6 +170,14 @@ class Compose(ODCSBase):
     scratch_build_tasks = db.Column(db.String, nullable=True)
     # White-space separated list of parent Pungi compose IDs (pungi_compose_id).
     parent_pungi_compose_ids = db.Column(db.String, nullable=True)
+    # White-space separate list of non-scratch modules (N:S:V:C) to include in a compose.
+    modules = db.Column(db.String, nullable=True)
+    # Pungi Compose ID of compose this compose respins.
+    respin_of = db.Column(db.String, nullable=True)
+    # The name of a base module the module buildrequires
+    base_module_br_name = db.Column(db.String, nullable=True)
+    # The stream of a base module the module buildrequires
+    base_module_br_stream = db.Column(db.String, nullable=True)
 
     @property
     def on_default_target_dir(self):
@@ -218,6 +226,10 @@ class Compose(ODCSBase):
         scratch_modules=None,
         parent_pungi_compose_ids=None,
         scratch_build_tasks=None,
+        modules=None,
+        respin_of=None,
+        base_module_br_name=None,
+        base_module_br_stream=None,
     ):
         now = datetime.utcnow()
         compose = cls(
@@ -245,6 +257,10 @@ class Compose(ODCSBase):
             scratch_modules=scratch_modules,
             parent_pungi_compose_ids=parent_pungi_compose_ids,
             scratch_build_tasks=scratch_build_tasks,
+            modules=modules,
+            respin_of=respin_of,
+            base_module_br_name=base_module_br_name,
+            base_module_br_stream=base_module_br_stream,
         )
         session.add(compose)
         return compose
@@ -293,6 +309,10 @@ class Compose(ODCSBase):
             scratch_modules=compose.scratch_modules,
             parent_pungi_compose_ids=compose.parent_pungi_compose_ids,
             scratch_build_tasks=compose.scratch_build_tasks,
+            modules=compose.modules,
+            respin_of=compose.respin_of,
+            base_module_br_name=compose.base_module_br_name,
+            base_module_br_stream=compose.base_module_br_stream,
         )
         session.add(compose)
         return compose
@@ -430,6 +450,10 @@ class Compose(ODCSBase):
             "scratch_modules": self.scratch_modules,
             "parent_pungi_compose_ids": self.parent_pungi_compose_ids,
             "scratch_build_tasks": self.scratch_build_tasks,
+            "modules": self.modules,
+            "respin_of": self.respin_of,
+            "base_module_br_name": self.base_module_br_name,
+            "base_module_br_stream": self.base_module_br_stream,
         }
 
         if full:
