@@ -148,8 +148,11 @@ def execute_cmd(args, stdout=None, stderr=None, cwd=None, timeout=None):
         raise RuntimeError(err_msg)
 
 
-def clone_repo(url, dest, branch="master", commit=None):
-    cmd = ["git", "clone", "-b", branch, url, dest]
+def clone_repo(url, dest, branch=None, commit=None):
+    cmd = ["git", "clone"]
+    if branch:
+        cmd += ["-b", branch]
+    cmd += [url, dest]
     execute_cmd(cmd)
 
     if commit:
@@ -170,3 +173,11 @@ def copytree(src, dst, symlinks=False, ignore=None):
             shutil.copytree(s, d, symlinks, ignore)
         else:
             shutil.copy2(s, d)
+
+
+def write_empty_repo(compose, arches):
+    """Create an empty repository for each of the given arches."""
+    for arch in arches:
+        repodir = os.path.join(compose.result_repo_dir, arch, "os")
+        makedirs(repodir)
+        execute_cmd(["createrepo_c", repodir])
