@@ -158,6 +158,10 @@ class ODCSAPI(MethodView):
         :jsonparam number seconds_to_live: Number of seconds before the compoose expires.
         :jsonparam list sigkeys: Optional list defining the :ref:`sigkeys<sigkeys>`.
             If not defined, original :ref:`sigkeys<sigkeys>` will be used.
+        :jsonparam object source: The JSON object allowing to override the source of compose.
+        :jsonparam list source["builds"]: List defining the :ref:`builds<builds>`.
+        :jsonparam list source["modules"]: List defining the :ref:`modules<modules>`.
+
 
         :statuscode 200: Compose updated and returned.
         :statuscode 401: User is unathorized.
@@ -198,6 +202,18 @@ class ODCSAPI(MethodView):
         else:
             sigkeys = old_compose.sigkeys
 
+        source_data = data.get("source", {})
+
+        modules = None
+        if "modules" in source_data:
+            modules = " ".join(source_data["modules"])
+
+        builds = None
+        if "builds" in source_data:
+            if not isinstance(source_data["builds"], list):
+                raise ValueError("builds should be a list")
+            builds = " ".join(source_data["builds"])
+
         # Get the raw_config_key if this compose is RAW_CONFIG.
         raw_config_key = None
         if old_compose.source_type == PungiSourceType.RAW_CONFIG:
@@ -216,6 +232,8 @@ class ODCSAPI(MethodView):
         has_to_create_a_copy = (
             old_compose.state in (COMPOSE_STATES["removed"], COMPOSE_STATES["failed"])
             or sigkeys != old_compose.sigkeys
+            or modules is not None
+            or builds is not None
         )
         if has_to_create_a_copy:
             log.info("%r: Going to regenerate the compose", old_compose)
@@ -226,6 +244,12 @@ class ODCSAPI(MethodView):
                 seconds_to_live,
                 sigkeys=sigkeys,
             )
+            if modules:
+                compose.modules = modules
+            if builds:
+                compose.builds = builds
+
+            compose.respin_of = old_compose.pungi_compose_id
             db.session.add(compose)
             # Flush is needed, because we use `before_commit` SQLAlchemy
             # event to send message and before_commit can be called before
@@ -267,7 +291,7 @@ class ODCSAPI(MethodView):
         :jsonparam list flags: List of :ref:`compose flags<flags>` defined as strings.
         :jsonparam list arches: List of :ref:`arches<arches>` the compose should be generated for.
         :jsonparam list multilib_arches: List of :ref:`multilib arches<multilib_arches>`.
-        :jsonparam string multilib_method: List defining the :ref:`multilib method<multilib_method>`.
+        :jsonparam list multilib_method: List defining the :ref:`multilib method<multilib_method>`.
         :jsonparam list lookaside_repos: List of :ref:`lookaside_repos<lookaside_repos>`.
         :jsonparam string label: String defining the :ref:`label<label>`.
         :jsonparam string compose_type: String defining the :ref:`compose_type<compose_type>`.
@@ -275,16 +299,21 @@ class ODCSAPI(MethodView):
         :jsonparam list parent_pungi_compose_ids: Pungi compose IDs of parent composes associated
             with this compose. They will be stored with this compose in the Compose Tracking
             Service.
+        :jsonparam string respin_of: Pungi compose ID of compose this compose respins.
+            It will be stored with this compose in the Compose Tracking Service.
         :jsonparam object source: The JSON object defining the source of compose.
         :jsonparam string source["type"]: String defining the :ref:`source type<source_type>`.
         :jsonparam string source["source"]: String defining the :ref:`source<source>`.
         :jsonparam list source["packages"]: List defining the :ref:`packages<packages>`.
         :jsonparam list source["builds"]: List defining the :ref:`builds<builds>`.
         :jsonparam list source["sigkeys"]: List defining the :ref:`sigkeys<sigkeys>`.
-        :jsonparam list source["koji_event"]: Number defining the :ref:`koji_event<koji_event>`.
+        :jsonparam number source["koji_event"]: Number defining the :ref:`koji_event<koji_event>`.
         :jsonparam list source["modular_koji_tags"]: List defining the :ref:`modular_koji_tags<modular_koji_tags>`.
         :jsonparam list source["scratch_modules"]: List defining the :ref:`scratch_modules<scratch_modules>`.
         :jsonparam list source["scratch_build_tasks"]: List defining the :ref:`scratch_build_tasks<scratch_build_tasks>`.
+        :jsonparam list source["modules"]: List defining the :ref:`modules<modules>`.
+        :jsonparam string source["base_module_br_name"]: String defining the :ref:`base_module_br_name<base_module_br_name>`.
+        :jsonparam string source["base_module_br_stream"]: String defining the :ref:`base_module_br_stream<base_module_br_stream>`.
 
         :statuscode 200: Compose request created and returned.
         :statuscode 401: Request not in valid format.
@@ -327,6 +356,10 @@ class ODCSAPI(MethodView):
             # Use list(set()) here to remove duplicate sources.
             source = list(set(source_data["source"].split(" ")))
 
+        modules = None
+        if "modules" in source_data:
+            modules = " ".join(source_data["modules"])
+
         scratch_modules = None
         if "scratch_modules" in source_data:
             scratch_modules = " ".join(source_data["scratch_modules"])
@@ -387,6 +420,8 @@ class ODCSAPI(MethodView):
 
         builds = None
         if "builds" in source_data:
+            if not isinstance(source_data["builds"], list):
+                raise ValueError("builds should be a list")
             builds = " ".join(source_data["builds"])
 
         sigkeys = ""
@@ -429,6 +464,8 @@ class ODCSAPI(MethodView):
         if "parent_pungi_compose_ids" in data:
             parent_pungi_compose_ids = " ".join(data["parent_pungi_compose_ids"])
 
+        respin_of = data.get("respin_of", None)
+
         multilib_method = MULTILIB_METHODS["none"]
         if "multilib_method" in data:
             for name in data["multilib_method"]:
@@ -462,6 +499,9 @@ class ODCSAPI(MethodView):
         if "scratch_build_tasks" in source_data:
             scratch_build_tasks = " ".join(source_data["scratch_build_tasks"])
 
+        base_module_br_name = source_data.get("base_module_br_name", None)
+        base_module_br_stream = source_data.get("base_module_br_stream", None)
+
         label = data.get("label", None)
         compose_type = data.get("compose_type", "test")
 
@@ -508,6 +548,10 @@ class ODCSAPI(MethodView):
             scratch_modules=scratch_modules,
             parent_pungi_compose_ids=parent_pungi_compose_ids,
             scratch_build_tasks=scratch_build_tasks,
+            modules=modules,
+            respin_of=respin_of,
+            base_module_br_name=base_module_br_name,
+            base_module_br_stream=base_module_br_stream,
         )
         db.session.add(compose)
         # Flush is needed, because we use `before_commit` SQLAlchemy event to
