@@ -92,8 +92,12 @@ class TestModels(ModelsBaseTest):
             "target_dir": "default",
             "toplevel_url": "http://localhost/odcs/odcs-1",
             "scratch_modules": None,
+            "modules": None,
             "parent_pungi_compose_ids": None,
             "scratch_build_tasks": None,
+            "respin_of": None,
+            "base_module_br_name": None,
+            "base_module_br_stream": None,
         }
         self.assertEqual(c.json(True), expected_json)
 
