@@ -97,6 +97,24 @@ class TestValidateJSONData(unittest.TestCase):
         data = {"packages": ["gcc-g++"]}
         validate_json_data(data)
 
+    def test_validate_json_data_not_list(self):
+        data = {"source": {"builds": "kernel-4.0-1.el8"}}
+        with self.assertRaises(ValueError) as ctx:
+            validate_json_data(data)
+        self.assertEqual("builds should be a list", str(ctx.exception))
+
+    def test_validate_json_data_not_str(self):
+        data = {"source": {"compose_type": 123}}
+        with self.assertRaises(ValueError) as ctx:
+            validate_json_data(data)
+        self.assertEqual("compose_type should be a string", str(ctx.exception))
+
+    def test_validate_json_data_not_int(self):
+        data = {"source": {"koji_event": "abc"}}
+        with self.assertRaises(ValueError) as ctx:
+            validate_json_data(data)
+        self.assertEqual("koji_event should be an integer", str(ctx.exception))
+
 
 class ViewBaseTest(ModelsBaseTest):
     def setUp(self):
@@ -362,9 +380,13 @@ class TestViews(ViewBaseTest):
             "pungi_compose_id": None,
             "target_dir": "default",
             "scratch_modules": None,
+            "modules": None,
             "toplevel_url": "http://localhost/odcs/odcs-%d" % data["id"],
             "parent_pungi_compose_ids": None,
             "scratch_build_tasks": None,
+            "respin_of": None,
+            "base_module_br_name": None,
+            "base_module_br_stream": None,
         }
         self.assertEqual(data, expected_json)
 
@@ -1024,6 +1046,42 @@ class TestViews(ViewBaseTest):
         c = db.session.query(Compose).filter(Compose.id == 3).one()
         self.assertEqual(c.reused_id, None)
 
+    def test_submit_respin(self):
+        self.c1.state = COMPOSE_STATES["done"]
+        self.c1.reused_id = 1
+        self.c1.koji_event = 123
+        self.c1.pungi_config_dump = "some data"
+        self.c1.pungi_compose_id = "Fedora-1-1"
+        db.session.commit()
+
+        with self.test_request_context(user="dev"):
+            flask.g.oidc_scopes = [
+                "{0}{1}".format(conf.oidc_base_namespace, "renew-compose")
+            ]
+
+            req = {
+                "source": {
+                    "modules": ["foo:stream:1:1", "bar:stream:1:1"],
+                    "builds": ["foo-1-1", "bar-1-1"],
+                    "unknown_arg": "should be ignored",
+                }
+            }
+
+            rv = self.client.patch("/api/1/composes/1", data=json.dumps(req))
+            data = json.loads(rv.get_data(as_text=True))
+
+        self.assertEqual(data["id"], 3)
+        self.assertEqual(data["state_name"], "wait")
+        self.assertEqual(data["modules"], "foo:stream:1:1 bar:stream:1:1")
+        self.assertEqual(data["builds"], "foo-1-1 bar-1-1")
+        self.assertEqual(data["respin_of"], "Fedora-1-1")
+        self.assertEqual(data["koji_event"], 123)
+        self.assertEqual(data["time_removed"], None)
+
+        c = db.session.query(Compose).filter(Compose.id == 3).one()
+        self.assertEqual(c.reused_id, None)
+        self.assertEqual(c.pungi_config_dump, "some data")
+
     def test_submit_build_not_allowed_source_type(self):
         with self.test_request_context(user="dev"):
             flask.g.oidc_scopes = [
@@ -1306,6 +1364,37 @@ class TestViews(ViewBaseTest):
                 "foo:bar:20200806:abcdefgh fooo:bar:20200810:abcdefgh",
             )
 
+    def test_submit_build_modules(self):
+        with self.test_request_context(user="dev"):
+            flask.g.oidc_scopes = [
+                "{0}{1}".format(conf.oidc_base_namespace, "new-compose")
+            ]
+
+            rv = self.client.post(
+                "/api/1/composes/",
+                data=json.dumps(
+                    {
+                        "source": {
+                            "type": "module",
+                            "source": "testmodule:master",
+                            "modules": [
+                                "foo:bar:20200806:abcdefgh",
+                                "fooo:bar:20200810:abcdefgh",
+                            ],
+                        }
+                    }
+                ),
+            )
+            data = json.loads(rv.get_data(as_text=True))
+            self.assertEqual(
+                data["source"],
+                "testmodule:master",
+            )
+            self.assertEqual(
+                data["modules"],
+                "foo:bar:20200806:abcdefgh fooo:bar:20200810:abcdefgh",
+            )
+
     def test_submit_build_only_scratch_modules(self):
         with self.test_request_context(user="dev"):
             flask.g.oidc_scopes = [
@@ -1355,6 +1444,27 @@ class TestViews(ViewBaseTest):
                 "Fedora-1-1 Fedora-2-2",
             )
 
+    def test_submit_build_respin_of(self):
+        with self.test_request_context(user="dev"):
+            flask.g.oidc_scopes = [
+                "{0}{1}".format(conf.oidc_base_namespace, "new-compose")
+            ]
+
+            rv = self.client.post(
+                "/api/1/composes/",
+                data=json.dumps(
+                    {
+                        "respin_of": "Fedora-1-1",
+                        "source": {"type": "module", "source": "testmodule:master"},
+                    }
+                ),
+            )
+            data = json.loads(rv.get_data(as_text=True))
+            self.assertEqual(
+                data["respin_of"],
+                "Fedora-1-1",
+            )
+
     def test_query_compose(self):
         resp = self.client.get("/api/1/composes/1")
         data = json.loads(resp.get_data(as_text=True))
@@ -1822,9 +1932,13 @@ class TestViews(ViewBaseTest):
             "pungi_compose_id": None,
             "target_dir": "default",
             "scratch_modules": None,
+            "modules": None,
             "toplevel_url": "http://localhost/odcs/odcs-%d" % data["id"],
             "parent_pungi_compose_ids": None,
             "scratch_build_tasks": None,
+            "respin_of": None,
+            "base_module_br_name": None,
+            "base_module_br_stream": None,
         }
         self.assertEqual(data, expected_json)
 
@@ -1907,9 +2021,7 @@ class TestExtendExpiration(ViewBaseTest):
 
             self.assertEqual(400, data["status"])
             self.assertEqual("Bad Request", data["error"])
-            self.assertIn(
-                "Invalid seconds_to_live specified in request", data["message"]
-            )
+            self.assertIn("seconds_to_live should be an integer", data["message"])
 
     @patch.object(conf, "auth_backend", new="noauth")
     def test_bad_request_if_request_data_is_not_json(self):
